# wxy-Mail

#### 介绍
发送邮件相关操作


#### 三方库
1. 安装twine
2. 安装setuptools


#### 使用教程

1. pip安装     pip install wxy-Mail
2. pip卸载     pip uninstall wxy-Mail
3. pip升级     pip install --upgrade wxy-Mail
4. 调用        from wxy_Mail import Mail